==> cds-feature-jdbc-1.34.7-sources.jar: com/sap/cds/services/impl/persistence/JdbcDataStoreConfiguration.java <==
package com.sap.cds.services.impl.persistence;

import com.sap.cds.DataStoreConfiguration;
import com.sap.cds.services.environment.CdsProperties;

class JdbcDataStoreConfiguration implements DataStoreConfiguration {

	private final CdsProperties cdsProperties;

	JdbcDataStoreConfiguration(CdsProperties cdsProperties) {
		this.cdsProperties = cdsProperties;
	}

	@Override
	@SuppressWarnings("deprecation")
	public String getProperty(String key) {
		switch (key) {
			case DOCSTORE_INTEGRATION_ENABLED:
				return Boolean.toString(cdsProperties.getSql().getHana().getDocstore().isEnabled());
			case COLLATE:
				return cdsProperties.getSql().getCollate();
			case IGNORE_LOCALE_ON_HANA:
				return Boolean.toString(cdsProperties.getSql().getHana().isIgnoreLocale());
			case SUPPORTED_LOCALES:
				return cdsProperties.getSql().getSupportedLocales();
			case IGNORE_VIRTUAL_ELEMENTS:
				return Boolean.toString(cdsProperties.getSql().isIgnoreVirtualElements());
			case MAX_BATCH_SIZE:
				return Integer.toString(cdsProperties.getSql().getMaxBatchSize());
			case USE_LOCALIZED_VIEW_SEARCH_RESOLVER:
				return Boolean.toString(cdsProperties.getSql().getSearch().isUseLocalizedView());
			case LOG_CQN_VALUES:
				return Boolean.toString(cdsProperties.getSecurity().isLogPotentiallySensitive());
			case UPSERT_STRATEGY:
				return cdsProperties.getSql().getUpsert().getStrategy();
			default:
				/*
				 * Once a property is part of CdsProperties the default is part of
				 * CdsProperties. Only if the key is unknown.
				 */
				return null;
		}
	}
}

==> cds-feature-jdbc-2.5.0-sources.jar: com/sap/cds/services/impl/persistence/JdbcDataStoreConfiguration.java <==
package com.sap.cds.services.impl.persistence;

import java.util.stream.Collectors;

import com.sap.cds.DataStoreConfiguration;
import com.sap.cds.services.environment.CdsProperties;

class JdbcDataStoreConfiguration implements DataStoreConfiguration {

	private final CdsProperties cdsProperties;

	JdbcDataStoreConfiguration(CdsProperties cdsProperties) {
		this.cdsProperties = cdsProperties;
	}

	@Override
	@SuppressWarnings("deprecation")
	public String getProperty(String key) {
		switch (key) {
			case DOCSTORE_INTEGRATION_ENABLED:
				return Boolean.toString(cdsProperties.getSql().getHana().getDocstore().isEnabled());
			case COLLATE:
				return cdsProperties.getSql().getCollate();
			case IGNORE_LOCALE_ON_HANA:
				return Boolean.toString(cdsProperties.getSql().getHana().isIgnoreLocale());
			case SUPPORTED_LOCALES:
				return cdsProperties.getSql().getSupportedLocales().stream().collect(Collectors.joining(","));
			case MAX_BATCH_SIZE:
				return Integer.toString(cdsProperties.getSql().getMaxBatchSize());
			case USE_LOCALIZED_VIEW_SEARCH_RESOLVER:
				return Boolean.toString(cdsProperties.getSql().getSearch().isUseLocalizedView());
			case LOG_CQN_VALUES:
				return Boolean.toString(cdsProperties.getSecurity().isLogPotentiallySensitive());
			case HANA_COMPATIBILITY_MODE:
				return HANA_COMPATIBILITY_MODE_HEX.equalsIgnoreCase(cdsProperties.getSql().getHana().getOptimizationMode())
						? HANA_COMPATIBILITY_MODE_HEX
						: HANA_COMPATIBILITY_MODE_LEGACY;
			default:
				/*
				 * Once a property is part of CdsProperties the default is part of
				 * CdsProperties. Only if the key is unknown.
				 */
				return null;
		}
	}
}
